==> gnome-control-center-2.91.91.tar.bz2: gnome-control-center-2.91.91/panels/background/gdesktop-enums-types.h <==



#ifndef __GDESKTOP_ENUMS_TYPES_H__
#define __GDESKTOP_ENUMS_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS
/* enumerations from "/home/hadess/Projects/gnome-install/include/gsettings-desktop-schemas/gdesktop-enums.h" */
GType g_desktop_proxy_mode_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_PROXY_MODE (g_desktop_proxy_mode_get_type())
GType g_desktop_toolbar_style_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_TOOLBAR_STYLE (g_desktop_toolbar_style_get_type())
GType g_desktop_toolbar_icon_size_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_TOOLBAR_ICON_SIZE (g_desktop_toolbar_icon_size_get_type())
GType g_desktop_background_style_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_BACKGROUND_STYLE (g_desktop_background_style_get_type())
GType g_desktop_background_shading_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_BACKGROUND_SHADING (g_desktop_background_shading_get_type())
GType g_desktop_mouse_dwell_mode_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_MOUSE_DWELL_MODE (g_desktop_mouse_dwell_mode_get_type())
GType g_desktop_mouse_dwell_direction_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_MOUSE_DWELL_DIRECTION (g_desktop_mouse_dwell_direction_get_type())
GType g_desktop_clock_format_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_CLOCK_FORMAT (g_desktop_clock_format_get_type())
GType g_desktop_screensaver_mode_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_SCREENSAVER_MODE (g_desktop_screensaver_mode_get_type())
GType g_desktop_magnifier_mouse_tracking_mode_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_MAGNIFIER_MOUSE_TRACKING_MODE (g_desktop_magnifier_mouse_tracking_mode_get_type())
GType g_desktop_magnifier_screen_position_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_MAGNIFIER_SCREEN_POSITION (g_desktop_magnifier_screen_position_get_type())
/* enumerations from "cc-background-item.h" */
GType cc_background_item_flags_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_BACKGROUND_ITEM_FLAGS (cc_background_item_flags_get_type())
G_END_DECLS

#endif /* __GDESKTOP_ENUMS_TYPES_H__ */

==> gnome-control-center-3.0.0.1.tar.bz2: gnome-control-center-3.0.0.1/panels/background/gdesktop-enums-types.h <==



#ifndef __GDESKTOP_ENUMS_TYPES_H__
#define __GDESKTOP_ENUMS_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS
/* enumerations from "/usr/include/gsettings-desktop-schemas/gdesktop-enums.h" */
GType g_desktop_proxy_mode_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_PROXY_MODE (g_desktop_proxy_mode_get_type())
GType g_desktop_toolbar_style_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_TOOLBAR_STYLE (g_desktop_toolbar_style_get_type())
GType g_desktop_toolbar_icon_size_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_TOOLBAR_ICON_SIZE (g_desktop_toolbar_icon_size_get_type())
GType g_desktop_background_style_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_BACKGROUND_STYLE (g_desktop_background_style_get_type())
GType g_desktop_background_shading_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_BACKGROUND_SHADING (g_desktop_background_shading_get_type())
GType g_desktop_mouse_dwell_mode_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_MOUSE_DWELL_MODE (g_desktop_mouse_dwell_mode_get_type())
GType g_desktop_mouse_dwell_direction_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_MOUSE_DWELL_DIRECTION (g_desktop_mouse_dwell_direction_get_type())
GType g_desktop_clock_format_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_CLOCK_FORMAT (g_desktop_clock_format_get_type())
GType g_desktop_screensaver_mode_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_SCREENSAVER_MODE (g_desktop_screensaver_mode_get_type())
GType g_desktop_magnifier_mouse_tracking_mode_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_MAGNIFIER_MOUSE_TRACKING_MODE (g_desktop_magnifier_mouse_tracking_mode_get_type())
GType g_desktop_magnifier_screen_position_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_MAGNIFIER_SCREEN_POSITION (g_desktop_magnifier_screen_position_get_type())
/* enumerations from "cc-background-item.h" */
GType cc_background_item_flags_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_BACKGROUND_ITEM_FLAGS (cc_background_item_flags_get_type())
G_END_DECLS

#endif /* __GDESKTOP_ENUMS_TYPES_H__ */
